@@ -49,8 +49,6 @@
 
 (defvar debian-copyright-mode-map nil
   "Keymap for debian/copyright mode.")
-(defvar debian-copyright-mode-syntax-table nil
-  "Syntax table for debian/copyright mode.")
 
 (defvar debian-copyright-font-lock-keywords nil
   "Regexps to highlight in font-lock.")
@@ -98,12 +96,13 @@ It should be immediately followed by a non-slash character.")
     "MPL-2\\.0")
   "Supported licenses based on /usr/share/common-licenses.")
 
-(if debian-copyright-mode-syntax-table
-    ()              ; Do not change the table if it is already set up.
-  (setq debian-copyright-mode-syntax-table (make-syntax-table))
-  (modify-syntax-entry ?\" ".   " debian-copyright-mode-syntax-table)
-  (modify-syntax-entry ?\\ ".   " debian-copyright-mode-syntax-table)
-  (modify-syntax-entry ?' "w   " debian-copyright-mode-syntax-table))
+(defvar debian-copyright-mode-syntax-table
+  (let ((table (make-syntax-table)))
+    (modify-syntax-entry ?\" ".   " table)
+    (modify-syntax-entry ?\\ ".   " table)
+    (modify-syntax-entry ?'  "w   " table)
+    table)
+  "Syntax table for debian/copyright mode.")
 
 (defun debian-copyright--font-lock-add-field-keywords (field-names)
   "Add font lock for field in FIELD-NAMES."
@@ -144,7 +143,7 @@ https://stackoverflow.com/a/201378."
   (kill-all-local-variables)
   (setq major-mode 'debian-copyright-mode)
   (setq mode-name "debian/copyright")
-  (mapc 'make-local-variable '(font-lock-defaults write-file-hooks))
+  (make-local-variable 'write-file-hooks)
   (use-local-map debian-copyright-mode-map)
   (set-syntax-table debian-copyright-mode-syntax-table)
   ;; Add font locks
@@ -157,13 +156,13 @@ https://stackoverflow.com/a/201378."
       (debian-copyright--font-lock-add-urls
        debian-copyright--supported-url-protocol-prefixes)
     (goto-address))
-  (setq font-lock-defaults
+  (setq-local font-lock-defaults
         '(debian-copyright-font-lock-keywords
           nil  ;keywords-only
           nil  ;case-fold
           ()   ;syntax-alist
           ))
-  (dpkg-dev-common-utils--add-debputy-settings 'debian-copyright-mode)
+  (dpkg-dev-common-utils--add-debputy-settings)
   (run-mode-hooks 'debian-copyright-mode-hook))
 
 
