@@ -54,8 +54,8 @@
   ;; this function could be simpler if xemacs supported %z, but
   ;; it doesn't, so we're shelling out to invoke date -R to obtain
   ;; Debian-policy-compliant date string.
-  (let* ((date-program "date -R")
-         (system-time-locale "C"))
+  (let ((date-program "date -R")
+        (system-time-locale "C"))
     (if (featurep 'xemacs)
         (replace-in-string (exec-to-string date-program) "\n" "")
       ;; if it's not xemacs, just use format-time-string
@@ -66,31 +66,31 @@
 Automatically invoked when saving file."
   (save-excursion
     (goto-char (point-min))
-    (if (re-search-forward "^ -- " nil t)
-        (delete-region (progn (beginning-of-line) (point)) (progn (end-of-line) (point)))
-      (goto-char (point-max))
-      (if (bolp)
-          (insert "\n")
-        (insert "\n\n")))
-    (insert (concat
-             " -- "
-             debian-changelog-full-name
-             " <" debian-changelog-mailing-address ">, "
-             (readme-debian-date-string)))
-    (if (and (= (point)(point-max)) (not (bolp)))
+    (cond
+     ((re-search-forward "^ -- " nil 1)
+      (delete-region (point-at-bol) (point-at-eol)))
+     ((bolp)
+      (insert "\n"))
+     (t
+      (insert "\n\n")))
+    (insert " -- "
+            debian-changelog-full-name
+            " <" debian-changelog-mailing-address ">, "
+            (readme-debian-date-string))
+    (if (and (eobp) (not (bolp)))
         (insert "\n"))))
 
-(defvar readme-debian-mode-map nil "Keymap for README.Debian mode.")
-(if readme-debian-mode-map
-    ()
-  (setq readme-debian-mode-map (make-sparse-keymap)))
-(defvar readme-debian-mode-syntax-table nil "Syntax table for README.Debian mode.")
-(if readme-debian-mode-syntax-table
-    ()                   ; Do not change the table if it is already set up.
-  (setq readme-debian-mode-syntax-table (make-syntax-table))
-  (modify-syntax-entry ?\" ".   " readme-debian-mode-syntax-table)
-  (modify-syntax-entry ?\\ ".   " readme-debian-mode-syntax-table)
-  (modify-syntax-entry ?' "w   " readme-debian-mode-syntax-table))
+(defvar readme-debian-mode-map
+  (make-sparse-keymap)
+  "Keymap for README.Debian mode.")
+
+(defvar readme-debian-mode-syntax-table
+  (let ((table (make-syntax-table)))
+    (modify-syntax-entry ?\" ".   " table)
+    (modify-syntax-entry ?\\ ".   " table)
+    (modify-syntax-entry ?'  "w   " table)
+    table)
+  "Syntax table for README.Debian mode.")
 
 (defvar font-lock-defaults)             ;For XEmacs byte-compilation
 ;;;###autoload
@@ -104,14 +104,13 @@ will be updated.
   (kill-all-local-variables)
   (setq major-mode 'readme-debian-mode)
   (setq mode-name "README.Debian")
-  (make-local-variable 'font-lock-defaults)
   (use-local-map readme-debian-mode-map)
   (set-syntax-table readme-debian-mode-syntax-table)
-  (setq font-lock-defaults
+  (setq-local font-lock-defaults
         '(readme-debian-font-lock-keywords
           nil ;; keywords-only? No, let it do syntax via table.
           nil ;; case-fold?
-          nil ;; Local syntax table.
+          ()  ;; Local syntax table.
           ))
   ;; add timestamp update func to write-contents-hooks
   (if (or (= emacs-major-version 20)
